@@ -3,9 +3,12 @@
 #' @param x An object of class logrrenv to be plotted.
 #' @param ... Additional graphical parameters passed to the \code{spatstat::image.im} function.  See details.
 #' @param conlist Additional argument passed to the \code{spatstat::contour.im} function.
-#' @details An important aspect of this plot is the color argument (\code{col}) used for displaying the regions outside the tolerance envelopes.  If NULL (the implicit default), then the default color palette used by \code{image.im} will be used.  Simpler schemes, e.g., c("blue", "white", "orange") can suffice. See the examples.
+#' @param main A main title for the plot.  Default is blank.
+#' @details An important aspect of this plot is the color argument (\code{col}) used for displaying the regions outside the tolerance envelopes.  If NULL (the implicit default), then the default color palette used by \code{spatstat::image.im} will be used.  Simpler schemes, e.g., c("blue", "white", "orange") can suffice. See the examples.
 #' @importFrom graphics plot
 #' @method plot logrrenv
+#' @seealso \code{\link[spatstat]{plot.im}}
+#' @seealso \code{\link[spatstat]{contour.im}}
 #' @export
 #' @examples
 #' data(grave)
@@ -15,7 +18,7 @@
 #' plot(rsim, col = c("blue", "white", "orange"), ribbon = FALSE, box = FALSE) 
 #' # alternate color scheme
 #' plot(rsim, col = topo.colors(12))
-plot.logrrenv = function(x, ..., conlist = list())
+plot.logrrenv = function(x, ..., conlist = list(), main = "")
 {
   if(!is.element("logrrenv", class(x))) stop("x should be an object from logrr function")
   
@@ -38,7 +41,7 @@ plot.logrrenv = function(x, ..., conlist = list())
     xtemp$v[which_na] = NA
 
     # arguments for image.im function
-    argi = list(x = xtemp, main = "", ...)
+    argi = list(x = xtemp, main = main, ...)
        
     # plot colors for regions outside tolerance envelopes
     do.call(spatstat::image.im, argi)
